@@ -6,8 +6,10 @@ class SecretsManagerReader(IAMPreset):
         super().__init__(resource)
 
     def apply(self, service):
+        resource = str(self.resource) if self.resource.endswith("-??????") else f"{self.resource}-??????"
+
         service.provider.iam.allow(
             "secretsmanager",
             ["secretsmanager:GetSecretValue"],
-            "arn:aws:secretsmanager:${aws:region}:${aws:accountId}:secret:" + self.resource,
+            "arn:aws:secretsmanager:${aws:region}:${aws:accountId}:secret:" + resource,
         )
